@@ -11,7 +11,7 @@ import time
 import hildon
 import gobject
 import re
-
+import thread
 from threading import Thread
 
 
@@ -94,7 +94,8 @@ class MyZoomSelect(gtk.Dialog):
         self.h_max.set_value(16)
         self.vbox.pack_start( self.h_max, True,True,0)
 
-        bt_download = gtk.Button("Download")
+        bt_download = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
+                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"Download")
         bt_download.connect("clicked", self.act_download)
         self.vbox.pack_start( bt_download, True, True, 0)
 
@@ -434,11 +435,11 @@ class google_routesearch:
         else:
              cmd = "espeak \"%s\""%( str)
         """
-        cmd = "espeak -v %s \"%s\""%( self.CONFIG['google_routesearch_speak_street_lang'], str)
+        cmd = "espeak -v %s \"%s\" &"%( self.CONFIG['google_routesearch_speak_street_lang'], str)
 
-        #print "[[[%s]]]"%cmd
+        print "[[[%s]]]"%cmd
         #return None
-        os.system( cmd )
+        os.system(cmd)
 
     def makeInit(self):
         pass
@@ -485,7 +486,7 @@ class google_routesearch:
                     if p[3] <> None:
                         self.markers_icons.append( self.osmMapa.osm.image_add( p[0], p[1], p[3] ) )
 
-            if self.CONFIG['gpslock'] == 0:
+            if self.osmMapa.get_gpslock() == 0:
 
                 t_lt, t_ln, b_lt, b_ln = self.osmMapa.osm.get_bbox()
                 t_lt, t_ln, b_lt, b_ln = math.degrees(t_lt), math.degrees(t_ln), math.degrees(b_lt), math.degrees(b_ln)
@@ -506,7 +507,7 @@ class google_routesearch:
             self.markers_icons = []
 
 
-        if len(self.points) > 0 and self.recalculate_in_progress == 0 and self.CONFIG['gpslock']:
+        if len(self.points) > 0 and self.recalculate_in_progress == 0 and self.osmMapa.get_gpslock():
             print "calculate route and espeak"
             cr = gdkdrawable.cairo_create()
             # find close point
@@ -569,6 +570,13 @@ class google_routesearch:
                 
                 
                 print res_scale," max ",int(self.CONFIG['google_routesearch_auto_recal'])
+                if res_scale > 60:
+                    self.osmMapa.draw_arrow(
+                                            gdkdrawable,
+                                            self.points[id_next][0],
+                                            self.points[id_next][1]
+                                            )
+                
                 if res_scale > int(self.CONFIG['google_routesearch_auto_recal']) and self.recalculate_in_progress == 0 and self.drive_mode == 1:
                     self.recalculate_in_progress = 1
                     self.clean_layer()
@@ -610,14 +618,21 @@ class google_routesearch:
                         speed = (dis_done/tTotal)*3600
                         self.rout_avg_speed = self.osmMapa.distance_to_string( speed )
                         t_todo = ((dis_total-dis_done)/speed)*60
-                        dist = "total:%s done %s in %i min. avr: %s/h at place in: %i min." % (
+                        if self.CONFIG['width'] < self.CONFIG['height']:
+                            break_line = "\n"
+                            yoff = 20
+                        else:
+                            break_line = ""
+                            yoff = 0
+                        dist = "total:%s done %s in %i %smin. avr: %s/h at place in: %i min." % (
                                                                self.osmMapa.distance_to_string(dis_total),
                                                                self.osmMapa.distance_to_string(dis_done),
                                                                (tTotal/60),
+                                                               break_line,
                                                                self.rout_avg_speed,
                                                                t_todo
                                                                )
-                        self.osmMapa.draw_cloud( cr, 150,-31, dist, 15, False)
+                        self.osmMapa.draw_cloud( cr, 150,-32-yoff, dist, 16, False)
 
                         if m[4]<> None:
                             ico = cairo.ImageSurface.create_from_png( m[4] )
@@ -699,6 +714,7 @@ class google_routesearch:
             self.osmMapa.osm.image_remove( i )
         self.icons = []
 
+        self.points = []
         self.markers = []
         self.markers_lang = []
         self.my_point = -1
@@ -889,26 +905,32 @@ class google_routesearch:
 
         hbox = gtk.HBox()
 
-        bt_a = gtk.Button(stock=gtk.STOCK_ADD)
+        bt_a = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
+                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"Add")
         bt_a.connect("clicked", self.on_add)
         hbox.pack_start( bt_a, True)
 
 
-        bt_c = gtk.Button(stock=gtk.STOCK_CLEAR)
+        bt_c = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
+                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"Clear")
         bt_c.connect("clicked", self.on_clean)
         hbox.pack_start( bt_c, True)
 
 
-        bt_swap = gtk.Button("swap points")
+        bt_swap = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
+                           hildon.BUTTON_ARRANGEMENT_VERTICAL, "swap points")
+        #bt_swap.set_text("swap points","some value")
         bt_swap.connect("clicked", self.on_swap)
         hbox.pack_start( bt_swap, True)
 
-        bt_search = gtk.Button(stock=gtk.STOCK_FIND)
+        bt_search = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
+                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"Find")
         bt_search.connect("clicked", self.on_search, dialog)
         hbox.pack_start( bt_search, True)
 
         if len( self.tracks ):
-            bt_clear = gtk.Button("clear")
+            bt_clear = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
+                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"clear")
             bt_clear.connect("clicked", self.on_clear, dialog)
             hbox.pack_start( bt_clear, True)
 
@@ -951,7 +973,8 @@ class google_routesearch:
             ve.pack_start(gtk.HSeparator(),True)
         
         if len( self.tracks ):
-            bt_export = gtk.Button("Export route to gpx")
+            bt_export = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
+                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"Export route to gpx")
             bt_export.connect("clicked", self.on_bt_export, dialog )
             ve.pack_start( bt_export, True)
             ve.pack_start(gtk.HSeparator(),True)
