@@ -63,6 +63,8 @@ gtk.gdk.threads_init()
 name = "yosmapa"
 version = "0.19"
 """
+0.19-6
+    recent search button fix up
 0.19-5
     move from gtk.Button to hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
                            hildon.BUTTON_ARRANGEMENT_VERTICAL,
@@ -553,7 +555,7 @@ class SearchDialog( hildon.Dialog):
 
 
     def on_recent_click(self,w):
-        CONFIG['search'] = w.get_label()
+        CONFIG['search'] = w.get_title()
         self.on_search(None)
 
 
